@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 import os
 import sys
-
-from nose.tools import assert_raises
+import pytest
 
 import subprocess
 
